@@ -1,4 +1,5 @@
 package Catalyst::Helper::View::Email::Template;
+our $VERSION = '0.17';
 
 use strict;
 
@@ -6,9 +7,13 @@ use strict;
 
 Catalyst::Helper::View::Email::Template - Helper for Templated Email Views
 
+=head1 VERSION
+
+version 0.17
+
 =head1 SYNOPSIS
 
-    script/create.pl view Template::Email Template::Email
+    $ script/myapp_create.pl view Email::Template Email::Template
 
 =head1 DESCRIPTION
 
@@ -82,4 +87,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
+1;
\ No newline at end of file
