@@ -1,15 +1,16 @@
 package # Hide me
     TestApp::View::Email::Template;
+our $VERSION = '0.17';
 
 use strict;
 use base 'Catalyst::View::Email::Template';
 
 __PACKAGE__->config(
     sender => {
-        method => 'Test'
+        mailer => 'Test'
     },
     stash_key       => 'email',
-    template_prefix => ''
+    template_prefix => '',
 );
 
 1;
