@@ -1,7 +1,8 @@
 package # Hide from PAUSE
     TestApp::View::Email::Template::AppConfig;
+our $VERSION = '0.17';
 
-use Email::Send::Test;
+use Email::Sender::Simple;
 
 use base 'Catalyst::View::Email::Template';
 
